@@ -19,7 +19,10 @@ import logging
 import netifaces
 import six
 
-from docker import Client
+try:
+    from docker import APIClient as Client
+except ImportError:
+    from docker import Client
 from tripleo_common.image.base import BaseImageManager
 from tripleo_common.image.exception import ImageUploaderException
 
@@ -93,7 +96,7 @@ class DockerImageUploader(ImageUploader):
     logger = logging.getLogger(__name__ + '.DockerImageUploader')
 
     def upload_image(self, image_name, pull_source, push_destination):
-        dockerc = Client(base_url='unix://var/run/docker.sock')
+        dockerc = Client(base_url='unix://var/run/docker.sock', version='auto')
         if ':' in image_name:
             image = image_name.rpartition(':')[0]
             tag = image_name.rpartition(':')[2]
